@@ -1,4 +1,4 @@
-# Copyright 2023-2024 Broadcom
+# Copyright 2023-2025 Broadcom
 # SPDX-License-Identifier: Apache-2.0
 import base64
 import json
@@ -159,11 +159,12 @@ class TrinoConnection(ManagedConnectionBase):
             raise recovery_cursor.get_exception()
 
     def execute_query(self, query):
-        res = self.execute_query_with_retries(query)
+        # first evaluate lineage because current behavior of 'explain create as select' fails if the table exists
         if self._lineage_logger:
             lineage_data = self._get_lineage_data(query)
-            if lineage_data:
-                self._lineage_logger.send(lineage_data)
+        res = self.execute_query_with_retries(query)
+        if self._lineage_logger and lineage_data:
+            self._lineage_logger.send(lineage_data)
         #  TODO: collect lineage for failed query
         return res
 
