@@ -1,4 +1,4 @@
-# Copyright 2023-2024 Broadcom
+# Copyright 2023-2025 Broadcom
 # SPDX-License-Identifier: Apache-2.0
 import logging
 import os
@@ -75,6 +75,12 @@ class TrinoPlugin:
                 connection_name,
             )
 
+            context.templates.add_template(
+                "scd1_upsert",
+                pathlib.Path(get_job_path("load/dimension/scd1_upsert")),
+                connection_name,
+            )
+
             context.templates.add_template(
                 "scd1",
                 pathlib.Path(get_job_path("load/dimension/scd1")),
